@@ -39,6 +39,11 @@ __PACKAGE__->collection_name('Preloads');
 
 has 'preloadId' => (is => 'rw', isa => 'Int', required => 1);
 __PACKAGE__->primary_key('preloadId');
+__PACKAGE__->params(
+    meetingId => 'Str',
+    fileName => 'Str',
+    length => 'Int',
+    );
 __PACKAGE__->_alias(key => 'preloadId');
 
 enum enumPreloadTypes => qw(media whiteboard plan);
@@ -92,47 +97,37 @@ MIME::Types.
 sub upload {
     my ($class, $insert_data_ref, %opt) = @_;
 
+    croak 'usage: $class->upload( {name => $filename, data => $binary_data, ...} )'
+	unless Elive::Util::_reftype($insert_data_ref) eq 'HASH'
+	&& $insert_data_ref->{data} && $insert_data_ref->{name};
+
+    my $connection = $opt{connection} || $class->connection
+	or die "not connected";
+
     my %insert_data = %{ $insert_data_ref };
 
     my $binary_data = delete $insert_data{data};
 
-    my $length = delete $insert_data{length} || 0;
-    $length ||= length($binary_data)
-	if $binary_data;
-
-    $opt{param}{length} = $length
-        if $length;
-
-    if ($insert_data{name}) {
-
-	$_ = File::Basename::basename($_)
-	    for $insert_data{name};
-
-	$insert_data{mimeType} ||= $class->_guess_mimetype($insert_data{name});
-	$insert_data{type}
-	||= ($insert_data{name} =~ m{\.wbd$}ix     ? 'whiteboard'
-	     : $insert_data{name} =~ m{\.elpx?$}ix ? 'plan'
-	     : 'media');
-    }
-
+    $insert_data{length} ||= length($binary_data);
+    $insert_data{ownerId} ||= $connection->login;
+    #
+    # 1. create initial record
+    #
     my $self = $class->insert(\%insert_data, %opt);
 
-    if ($length && $binary_data) {
-
-	my $adapter = $self->check_adapter('streamPreload');
-
-	my $connection = $self->connection
-	    or die "not connected";
-
-	my $som = $connection->call($adapter,
+    if ($insert_data{length} && $binary_data) {
+	#
+	# 2. Now upload data to it
+	#
+	my $som = $connection->call('streamPreload',
 				    preloadId => $self->preloadId,
-				    length => $length,
+				    length => $insert_data{length},
 				    stream => (SOAP::Data
 					       ->type('hexBinary')
 					       ->value($binary_data)),
 	    );
 
-	$self->_check_for_errors($som);
+	$connection->_check_for_errors($som);
     }
 
     return $self;
@@ -155,18 +150,14 @@ sub download {
     die "unable to get a preload_id"
 	unless $preload_id;
 
-    my $adapter = $self->check_adapter('getPreloadStream');
-
     my $connection = $self->connection
 	or die "not connected";
 
-    my $som = $connection->call($adapter,
+    my $som = $connection->call('getPreloadStream',
 				preloadId => Elive::Util::_freeze($preload_id, 'Int'),
 	);
 
-    $self->_check_for_errors($som);
-
-    my $results = $self->_get_results($som);
+    my $results = $self->_get_results($som, $connection);
 
     return  Elive::Util::_hex_decode($results->[0])
 	if $results->[0];
@@ -194,26 +185,14 @@ extension using MIME::Types.
 sub import_from_server {
     my ($class, $insert_data, %opt) = @_;
 
-    my $filename = delete $insert_data->{fileName};
+    my $params = $opt{param} || {};
 
-    die "missing fileName parameter"
-	unless $filename;
+    die "missing required parameter: fileName"
+	unless $insert_data->{fileName} || $params->{fileName};
 
-    $insert_data->{mimeType} ||= $class->_guess_mimetype($filename);
-    $insert_data->{type} 
-	||= ($filename =~ m{\.wbd}ix     ? 'whiteboard'
-	     : $filename =~ m{\.elpx?}ix ? 'plan'
-	     : 'media');
+    $opt{command} ||= 'importPreload',;
 
-    $insert_data->{name} ||= File::Basename::basename($filename);
-
-    $opt{param}{fileName} = $filename;
-
-    my $adapter = $class->check_adapter('importPreload');
-
-    return $class->insert($insert_data,
-			  adapter => $adapter,
-			  %opt);
+    return $class->insert($insert_data, %opt);
 }
 
 =head2 list_meeting_preloads
@@ -230,12 +209,33 @@ sub list_meeting_preloads {
     die 'usage: $preload_obj->list_meeting_preloads($meeting)'
 	unless $meeting_id;
 
-    my $adapter = $self->check_adapter('listMeetingPreloads');
+    $opt{command} ||= 'listMeetingPreloads';
 
-    return $self->_fetch({meetingId => $meeting_id},
-			 adapter => $adapter,
-			 %opt
-	);
+    return $self->_fetch({meetingId => $meeting_id}, %opt);
+}
+
+sub _freeze {
+    my ($class, $db_data, %opt) = @_;
+
+    $db_data = $class->SUPER::_freeze( $db_data, %opt);
+
+    if (my $filename = $db_data->{fileName}) {
+	$db_data->{name} ||= File::Basename::basename($filename);
+    }
+
+    if ($db_data->{name}) {
+
+	$_ = File::Basename::basename($_)
+	    for $db_data->{name};
+
+	$db_data->{mimeType} ||= $class->_guess_mimetype($db_data->{name});
+	$db_data->{type}
+	||= ($db_data->{name} =~ m{\.wbd$}ix     ? 'whiteboard'
+	     : $db_data->{name} =~ m{\.elpx?$}ix ? 'plan'
+	     : 'media');
+    }
+
+    return $db_data;
 }
 
 sub _thaw {
